@@ -19,8 +19,6 @@ from neutron_lib.api.definitions import allowedaddresspairs
 from neutron_lib.api.definitions import auto_allocated_topology
 from neutron_lib.api.definitions import availability_zone
 from neutron_lib.api.definitions import availability_zone_filter
-from neutron_lib.api.definitions import bfd_for_extraroutes
-from neutron_lib.api.definitions import bfd_monitor
 from neutron_lib.api.definitions import bgp
 from neutron_lib.api.definitions import bgp_4byte_asn
 from neutron_lib.api.definitions import bgp_associations
@@ -67,7 +65,6 @@ from neutron_lib.api.definitions import l3_ext_gw_mode
 from neutron_lib.api.definitions import l3_ext_ha_mode
 from neutron_lib.api.definitions import l3_ext_ndp_proxy
 from neutron_lib.api.definitions import l3_flavors
-from neutron_lib.api.definitions import l3_multi_ext_gw
 from neutron_lib.api.definitions import l3_ndp_proxy
 from neutron_lib.api.definitions import l3_port_ip_change_not_allowed
 from neutron_lib.api.definitions import local_ip
@@ -85,6 +82,7 @@ from neutron_lib.api.definitions import network_segment_range
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
 from neutron_lib.api.definitions import port_device_profile
+from neutron_lib.api.definitions import port_mac_address_override
 from neutron_lib.api.definitions import port_mac_address_regenerate
 from neutron_lib.api.definitions import port_numa_affinity_policy
 from neutron_lib.api.definitions import port_resource_request
@@ -107,6 +105,7 @@ from neutron_lib.api.definitions import qos_pps_minimum_rule
 from neutron_lib.api.definitions import qos_pps_minimum_rule_alias
 from neutron_lib.api.definitions import qos_pps_rule
 from neutron_lib.api.definitions import qos_rule_type_details
+from neutron_lib.api.definitions import qos_rule_type_filter
 from neutron_lib.api.definitions import qos_rules_alias
 from neutron_lib.api.definitions import quota_check_limit
 from neutron_lib.api.definitions import rbac_address_groups
@@ -139,10 +138,12 @@ from neutron_lib.api.definitions import subnet_segmentid_writable
 from neutron_lib.api.definitions import subnet_service_types
 from neutron_lib.api.definitions import subnetpool
 from neutron_lib.api.definitions import subnetpool_prefix_ops
+from neutron_lib.api.definitions import taas
 from neutron_lib.api.definitions import tag_ports_during_bulk_creation
 from neutron_lib.api.definitions import trunk
 from neutron_lib.api.definitions import trunk_details
 from neutron_lib.api.definitions import uplink_status_propagation
+from neutron_lib.api.definitions import vlan_filter
 from neutron_lib.api.definitions import vlantransparent
 from neutron_lib.api.definitions import vpn
 from neutron_lib.api.definitions import vpn_endpoint_groups
@@ -159,8 +160,6 @@ _ALL_API_DEFINITIONS = {
     auto_allocated_topology,
     availability_zone,
     availability_zone_filter,
-    bfd_for_extraroutes,
-    bfd_monitor,
     bgp,
     bgp_4byte_asn,
     bgp_associations,
@@ -207,7 +206,6 @@ _ALL_API_DEFINITIONS = {
     l3_ext_ha_mode,
     l3_ext_ndp_proxy,
     l3_flavors,
-    l3_multi_ext_gw,
     l3_ndp_proxy,
     l3_port_ip_change_not_allowed,
     local_ip,
@@ -225,6 +223,7 @@ _ALL_API_DEFINITIONS = {
     pagination,
     port,
     port_device_profile,
+    port_mac_address_override,
     port_mac_address_regenerate,
     port_numa_affinity_policy,
     port_resource_request,
@@ -247,6 +246,7 @@ _ALL_API_DEFINITIONS = {
     qos_pps_minimum_rule_alias,
     qos_pps_rule,
     qos_rule_type_details,
+    qos_rule_type_filter,
     qos_rules_alias,
     quota_check_limit,
     rbac_address_groups,
@@ -279,10 +279,12 @@ _ALL_API_DEFINITIONS = {
     subnet_service_types,
     subnetpool,
     subnetpool_prefix_ops,
+    taas,
     tag_ports_during_bulk_creation,
     trunk,
     trunk_details,
     uplink_status_propagation,
+    vlan_filter,
     vlantransparent,
     vpn,
     vpn_endpoint_groups,
